package com.op.wms.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.op.wms.mapper.OdsProcureOutOrderMapper;
import com.op.wms.domain.OdsProcureOutOrder;
import com.op.wms.service.IOdsProcureOutOrderService;

/**
 * 包材出库单Service业务层处理
 * 
 * @author Open Platform
 * @date 2023-07-06
 */
@Service
public class OdsProcureOutOrderServiceImpl implements IOdsProcureOutOrderService {
	@Autowired
	private OdsProcureOutOrderMapper odsProcureOutOrderMapper;

	/**
	 * 查询包材出库单
	 * 
	 * @param ID 包材出库单主键
	 * @return 包材出库单
	 */
	@Override
	public OdsProcureOutOrder selectOdsProcureOutOrderByID(String ID) {
		return odsProcureOutOrderMapper.selectOdsProcureOutOrderByID(ID);
	}

	/**
	 * 查询包材出库单列表
	 * 
	 * @param odsProcureOutOrder 包材出库单
	 * @return 包材出库单
	 */
	@Override
	public List<OdsProcureOutOrder> selectOdsProcureOutOrderList(OdsProcureOutOrder odsProcureOutOrder) {
		return odsProcureOutOrderMapper.selectOdsProcureOutOrderList(odsProcureOutOrder);
	}

	/**
	 * 新增包材出库单
	 * 
	 * @param odsProcureOutOrder 包材出库单
	 * @return 结果
	 */
	@Override
	public int insertOdsProcureOutOrder(OdsProcureOutOrder odsProcureOutOrder) {
		return odsProcureOutOrderMapper.insertOdsProcureOutOrder(odsProcureOutOrder);
	}

	/**
	 * 修改包材出库单
	 * 
	 * @param odsProcureOutOrder 包材出库单
	 * @return 结果
	 */
	@Override
	public int updateOdsProcureOutOrder(OdsProcureOutOrder odsProcureOutOrder) {
		return odsProcureOutOrderMapper.updateOdsProcureOutOrder(odsProcureOutOrder);
	}

	/**
	 * 批量删除包材出库单
	 * 
	 * @param IDs 需要删除的包材出库单主键
	 * @return 结果
	 */
	@Override
	public int deleteOdsProcureOutOrderByIDs(String[] IDs) {
		return odsProcureOutOrderMapper.deleteOdsProcureOutOrderByIDs(IDs);
	}

	/**
	 * 删除包材出库单信息
	 * 
	 * @param ID 包材出库单主键
	 * @return 结果
	 */
	@Override
	public int deleteOdsProcureOutOrderByID(String ID) {
		return odsProcureOutOrderMapper.deleteOdsProcureOutOrderByID(ID);
	}
}
